;;; org-config.el --- Configuración de org-mode

;; Author: kj <webmaster@outcontrol.net>
;; URL: https://git.kj2.me/kj/confi-emacs-actual

;;; Commentary:

;;; Code:
(defun kj/org-hook ()
  "Configuración para el hook de 'org-mode'."
  (display-line-numbers-mode 0)
  (variable-pitch-mode 1)
  (visual-line-mode 1)
  (visual-fill-column-mode 1)

  ;; Configuración de font
  (set-face-attribute (car face) nil :font "Cantarell" :weight 'regular :height (cdr face))
)

(use-package org
  :defer t
  :pin org
  :hook
  (org-mode . kj/org-hook)
  :config
  (setq org-ellipsis " ▾")
  (setq org-hide-emphasis-markers t)
  (setq org-startup-folded 'content)

  (setq org-agenda-start-with-log-mode t)
  (setq org-log-done 'time)
  (setq org-log-into-drawer t)
  (setq org-cycle-separator-lines -1)

  (org-indent-mode)

  ;; Palabras claves del To Do de org-mode
  (setq org-todo-keywords
        ;;'((sequence "☐" "✔" "⌛" "❌")))
        '((sequence "TODO(t)" "DOING(n)" "WAITING(w)" "|" "DONE(d!)" "CANCELED(c!)")))
  (setq org-todo-keyword-faces
        '(("TODO" . "#ff6464")
          ("DOING" . "yellow")
          ("DONE" . "green")
          ("WAITING" . "orange")
          ("CANCELED" . "#aaa"))
        )

  ;; Archivos a usarse en org-agenda
  (setq org-agenda-files
        '("~/Proyectos/ORGenda/Ideas.org"
          "~/Proyectos/ORGenda/IdeasTwitch.org"
          "~/Proyectos/ORGenda/Proyectos.org"
          "~/Proyectos/ORGenda/Tareas.org")
        )

  ;; Archivos entre los que se moverán las tareas
  (setq org-refile-targets
        '(("Archivo.org" :maxlevel . 1)
          ("Proyectos.org" :maxlevel . 1)
          ("IdeasTwitch.org" :maxlevel . 1)
          ("Ideas.org" :maxlevel . 1)
          ("Tareas.org" :maxlevel . 1)))

  ;; Guardar los archivos cuando se muevan tareas entre ellos
  (advice-add 'org-refile :after 'org-save-all-org-buffers)

  (setq org-capture-templates
        `(("t" "Tareas / Projectos")
          ("tt" "Tareas" entry (file+olp "~/Proyectos/ORGenda/Tareas.org")
           "* TODO %?\n  %U\n  %a\n  %i" :empty-lines 1)
          ("tp" "Proyectos" entry (file+olp "~/Proyectos/ORGenda/Proyectos.org")
           "* TODO %?\n  %U\n  %a\n  %i" :empty-lines 1)
          ("i" "Ideas")
          ("ii" "Ideas General" entry
           (file+olp "~/Proyectos/ORGenda/ideas.org")
           "* TODO %?\n   %a\n  %i" :empty-lines 1)
          ("it" "Ideas Twitch" entry
           (file+olp "~/Proyectos/ORGenda/IdeasTwitch.org")
           "* TODO %?\n   %a\n  %i" :empty-lines 1)
          )
        )
  )

(use-package org-superstar
  :hook
  (org-mode . org-superstar-mode)
  :config
  (setq org-superstar-special-todo-items t)
  ;; Eliminar los puntitos anteriores a un heading.
  (setq org-hide-leading-stars nil)
  (setq org-superstar-leading-bullet ?\s)
  )

(use-package visual-fill-column
  :config
  ;; Tamaño de la columna
  (setq visual-fill-column-width 150)
  ;; Centrar el texto
  (setq-default visual-fill-column-center-text t)
  )

(provide 'org-config)
;;; org-config.el ends here
